@@ -3,11 +3,11 @@
 |''Description''|adaptor for interacting with TiddlyWeb|
 |''Author:''|FND|
 |''Contributors''|Chris Dent, Martin Budden|
-|''Version''|0.9.3|
+|''Version''|0.10.2|
 |''Status''|stable|
 |''Source''|http://svn.tiddlywiki.org/Trunk/association/adaptors/TiddlyWebAdaptor.js|
 |''CodeRepository''|http://svn.tiddlywiki.org/Trunk/association/|
-|''License''|[[Creative Commons Attribution-ShareAlike 3.0 License|http://creativecommons.org/licenses/by-sa/3.0/]]|
+|''License''|[[BSD|http://www.opensource.org/licenses/bsd-license.php]]|
 |''CoreVersion''|2.5|
 |''Keywords''|serverSide TiddlyWeb|
 !Notes
@@ -32,6 +32,8 @@ This plugin includes [[jQuery JSON|http://code.google.com/p/jquery-json/]].
 * fixed ETag format
 !!v0.9 (2009-08-17)
 * fixed ETag handling for new tiddlers
+!!v0.10 (2009-10-08)
+* minor fixes
 !To Do
 * createWorkspace
 * document custom/optional context attributes (e.g. filters, query, revision) and tiddler fields (e.g. server.title, origin)
@@ -222,6 +224,8 @@ adaptor.prototype.getTiddlerRevision = function(title, revision, context, userPa
 };
 
 // retrieve an individual tiddler
+//# context is an object with members host and workspace
+//# callback is passed the new context and userParams
 adaptor.prototype.getTiddler = function(title, context, userParams, callback) {
 	context = this.setContext(context, userParams, callback);
 	context.title = title;
@@ -266,6 +270,7 @@ adaptor.getTiddlerCallback = function(status, context, responseText, uri, xhr) {
 			Date.convertFromYYYYMMDDHHMM(t.created), context.tiddler.fields); // XXX: merge extended fields!?
 		context.tiddler.fields["server.workspace"] = t.bag ? "bags/" + t.bag : "recipes/" + t.recipe; // XXX: bag is always supplied!?
 		context.tiddler.fields["server.page.revision"] = t.revision;
+		context.tiddler.fields["server.permissions"] = t.permissions.join(", ");
 	}
 	if(context.callback) {
 		context.callback(context, context.userParams);
@@ -402,9 +407,9 @@ adaptor.putTiddlerStoreCallback = function(status, context, responseText, uri, x
 	}
 };
 
-// rename an individual tiddler or move it to a different workspace -- TODO: make (from|to).title optional
-//# @param {Object} from source tiddler; members title and workspace (optional)
-//# @param {Object} to target tiddler; members title and workspace (optional) -- N.B.: workspace must be a bag
+// rename an individual tiddler or move it to a different workspace -- TODO: make {from|to}.title optional
+//# from and to are objects with members title and workspace (bag; optional),
+//# representing source and target tiddler, respectively
 adaptor.prototype.moveTiddler = function(from, to, context, userParams, callback) { // XXX: rename parameters (old/new)?
 	var _this = this;
 	var newTiddler = store.getTiddler(from.title) || store.getTiddler(to.title); //# local rename might already have occurred
